@@ -1,4 +1,5 @@
-from models.model import ClientModel
+from .models.model import ClientModel
+from abc import abstractmethod
 import pyodbc
 class DatabaseClient(ClientModel):
     def __init__(self, server, database, username, password, driverLocation, *args, **kwargs):
