@@ -1,8 +1,8 @@
-from models.model import ClientModel
+from .models.model import ClientModel
 import redis
 
 class RedisClient(ClientModel):
-    def __init__(self, host, port, db, charset="utf-8", decode_responses=True, *args, **kwargs):
+    def __init__(self, host, port, db, *args, charset="utf-8", decode_responses=True, **kwargs):
         self.host=host
         self.port=port
         self.db=db
